@@ -1,6 +1,6 @@
 from symbl.jobs_api.Job import Job
-from symbl.jobs_api.JobStatus import JobStatus
 from symbl.conversations_api.ConversationsApi import ConversationsApi
+from symbl.utils.Logger import Log
 
 
 def validate_conversation_id(function):
@@ -9,7 +9,7 @@ def validate_conversation_id(function):
         if self.get_conversation_id() != None:
             return function(*args, **kwargs)
         else:
-            raise ValueError('Conversation not initialized')
+            Log.getInstance().error("Conversation not initialized")
     return wrapper
 class Conversation():
 
@@ -62,7 +62,7 @@ class Conversation():
         return self.__conversation_api.get_members(self.__conversation_id, credentials=self.__credentials)
   
     @validate_conversation_id
-    def get_messages(self, parameters={}):  
+    def get_messages(self, parameters={}):
         return self.__conversation_api.get_messages(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
   
     @validate_conversation_id
@@ -70,5 +70,5 @@ class Conversation():
         return self.__conversation_api.get_questions(self.__conversation_id, credentials=self.__credentials)
   
     @validate_conversation_id
-    def get_topics(self, parameters={}):  
+    def get_topics(self, parameters={}):
         return self.__conversation_api.get_topics(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
\ No newline at end of file
