@@ -1,6 +1,4 @@
 from __future__ import absolute_import
-from symbl.utils import Log
-from symbl_rest import  JobsApi, ApiClient
 
 from symbl.async_api.Audio import Audio
 from symbl.async_api.Video import Video
@@ -12,8 +10,6 @@ from symbl.streaming_api.StreamingConnection import StreamingConnection
 from symbl.conversations_api.ConversationsApi import ConversationsApi
 from symbl.telephony_api.TelephonyApi import TelephonyApi
 from symbl.streaming_api.StreamingApi import StreamingApi
-from symbl.jobs_api.Job import Job
-from symbl.jobs_api.JobStatus import JobStatus
 
 Audio = Audio()
 Video = Video()
